CppFlags: Compiler flags for packages linking against VTK

View source: R/vtk.R

CppFlagsR Documentation

Compiler flags for packages linking against VTK

Description

Returns the C pre-processor flags (-I paths) required to compile C++ code that includes VTK headers. Intended to be called from a downstream package's configure or configure.win script:

Usage

CppFlags()

Details

VTK_CPPFLAGS="$("${R_HOME}/bin/Rscript" --vanilla -e "rvtk::CppFlags()")"

Value

A single character string of compiler flags, written to stdout (so that it can be captured by shell command substitution in configure) and returned invisibly.

Examples

flags <- CppFlags()

rvtk documentation built on May 11, 2026, 9:09 a.m.