| CppFlags | R Documentation |
Returns the C pre-processor flags (-I paths) required to compile C++ code
that includes VTK headers. Intended to be called from a downstream
package's configure or configure.win script:
CppFlags()
VTK_CPPFLAGS="$("${R_HOME}/bin/Rscript" --vanilla -e "rvtk::CppFlags()")"
A single character string of compiler flags, written to stdout (so
that it can be captured by shell command substitution in configure) and
returned invisibly.
flags <- CppFlags()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.