| LdFlags | R Documentation |
Returns the linker flags (-L paths and -l library names) required to
link C++ code against VTK. Intended to be called from a downstream
package's configure or configure.win script:
LdFlags()
VTK_LIBS="$("${R_HOME}/bin/Rscript" --vanilla -e "rvtk::LdFlags()")"
On Windows the full set of VTK linker flags can exceed the 8 191-character
command-line limit. Prefer LdFlagsFile() on Windows to write the flags
to a response file instead.
A single character string of linker flags, written to stdout (so
that it can be captured by shell command substitution in configure) and
returned invisibly.
flags <- LdFlags()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.